# UKBB ldsc site

Scripts used for generating the [results site](https://nealelab.github.io/UKBB_ldsc/) for LD score regression ([LDSC](https://github.com/bulik/ldsc)) analysis of the [UK Biobank GWAS](https://github.com/Nealelab/UK_Biobank_GWAS) produced by the [Neale Lab](http://www.nealelab.is/uk-biobank). You can read more about that GWAS effort [here](http://www.nealelab.is/blog/2017/7/19/rapid-gwas-of-thousands-of-phenotypes-for-337000-samples-in-the-uk-biobank) and read the [hertiabililty analysis post](http://www.nealelab.is/blog/2017/9/15/heritability-of-2000-traits-and-disorders-in-the-uk-biobank) for our initial thoughts on these results.

Contents of the site include:

* [Results browser](https://nealelab.github.io/UKBB_ldsc/h2_browser.html)
* [Interactive plots](https://nealelab.github.io/UKBB_ldsc/viz_h2.html)
* [Extended methods descriptions](https://nealelab.github.io/UKBB_ldsc/confidence.html)
* [Detailed results pages per phenotype](https://nealelab.github.io/UKBB_ldsc/h2_summary_50_irnt.html)
* [Downloads page](https://nealelab.github.io/UKBB_ldsc/downloads.html)

Scripts used for the LD Score regression analysis itself are in the [UKBB_ldsc_scripts](https://github.com/Nealelab/UKBB_ldsc_scripts) dependency. They've been separated to make it easier for you to pull//fork/otherwise use those scripts without ending up with a download of the whole results site.

## Version History

* **September 2017:** first release
* **October 2019:** round2 release

## Main contents of this repo

* `./site_build/build_site.R`: main driver script to build the static website using [R Markdown](https://rmarkdown.rstudio.com/). Copies the necessary source files into this directory and updates `_site.yml` to allow a clean build. Includes options to only generate a subset of the site for easier testing.
* `./docs/`: The full contents of the [results site](https://nealelab.github.io/UKBB_ldsc/) hosted on Github Pages.
* `./UKBB_ldsc_scripts/`: code for the LDSR analysis, including the Rmd files for results processing that are included in the methods section of this site. See the [UKBB_ldsc_scripts repo](https://github.com/Nealelab/UKBB_ldsc_scripts) for full description.
* `./site_source/`: source code for building the site, including:
 * `./rmd_source/`: R markdown source for each page of the site. `_h2_part_template.html` is used to generate each of the individual phenotype pages, adapting to the results for that phenotype.
 * `./yml_source/`: yaml code for the structure of the site and the pass parameters for rendering each page. Split into pieces to allow testing rendering subsets of the site. Full site yaml is stitched together by `./site_build/build_site.R` at run time.
 * `analytics_header.html`: page header code to count hits and downloads
 * `./sandflat` and `dt_styles.css`: custom CSS based on [Bootswatch themes](https://bootswatch.com/3/) and styling options for [Datatables](https://datatables.net/)
 * `make_favicon.R` and `./icon/`: favicon images for browser tabs on various platforms

## Credits

Site generated by Raymond Walters (i.e. all mistakes are his), with helpful improvements from Duncan Palmer and support from the full Neale Lab UKB team. See the site for [full credits](https://nealelab.github.io/UKBB_ldsc/credits.html) for this project.

For any questions/comments/feedback, email **nealelab.ukb@gmail.com**.
